==> twilight_1.18.0.zip: twilight/doc/tr_2004_01.R <==
###################################################
### chunk number 1:  eval=FALSE
###################################################
## q(save="no")
## 


###################################################
### chunk number 2: 
###################################################
library(splines)
library(stats)
library(golubEsets)
library(vsn)
oldopt <- options(digits=3)
on.exit( {options(oldopt)} )
options(width=75)


###################################################
### chunk number 3: 
###################################################
data(Golub_Train)
golubNorm <- justvsn(Golub_Train)
id <- as.numeric(Golub_Train$ALL.AML) #$


###################################################
### chunk number 4: 
###################################################
Golub_Train$ALL.AML #$
id


###################################################
### chunk number 5: 
###################################################
library(twilight)
pval <- twilight.pval(golubNorm, id, B=100)


###################################################
### chunk number 6: 
###################################################
data(expval)
expval


###################################################
### chunk number 7: 
###################################################
class(expval)
names(expval)


###################################################
### chunk number 8: 
###################################################
names(expval$result) #$


###################################################
### chunk number 9: 
###################################################
expval$result[1:7,1:5] #$


###################################################
### chunk number 10: 
###################################################
bitmap(file="tr_2004_01-scores.png",width=6,height=4.5,pointsize=10)
plot(expval,which="scores",grayscale=F,legend=F)
dev.off()
bitmap(file="tr_2004_01-qvalues.png",width=6,height=4.5,pointsize=10)
plot(expval,which="qvalues")
dev.off()


###################################################
### chunk number 11: 
###################################################
expval$pi0 #$


###################################################
### chunk number 12: 
###################################################
gene <- exprs(golubNorm)[pval$result$index[1],]
corr <- twilight.pval(golubNorm,gene,method="spearman",quant.ci=0.99,B=100)
corr


###################################################
### chunk number 13: 
###################################################
corr$result[1:10,1:5] #$


###################################################
### chunk number 14: 
###################################################
bitmap(file="tr_2004_01-corr.png",width=6,height=4.5,pointsize=10)
plot(corr,which="scores",grayscale=F,legend=F)
dev.off()


###################################################
### chunk number 15: 
###################################################
yperm <- twilight.filtering(golubNorm,id,method="fc",num.perm=50,num.take=10)
dim(yperm)


###################################################
### chunk number 16: 
###################################################
yperm <- yperm[-1,]
b <- twilight.pval(golubNorm,yperm[1,],method="fc",yperm=yperm)
hist(b$result$pvalue,col="gray",br=20)


###################################################
### chunk number 17: 
###################################################
bitmap(file="tr_2004_01-hist.png",width=6,height=4.5,pointsize=10)
hist(b$result$pvalue,col="gray",br=20,main="",xlab="P-value")
dev.off()


###################################################
### chunk number 18: 
###################################################
data(exfdr)
exfdr



###################################################
### chunk number 19: 
###################################################
exfdr$result[1:5,6:9] #$


###################################################
### chunk number 20: 
###################################################
bitmap(file="tr_2004_01-fdr.png",width=6,height=4.5,pointsize=10)
plot(exfdr,which="fdr",grayscale=F,legend=T)
dev.off()
bitmap(file="tr_2004_01-volcano.png",width=6,height=4.5,pointsize=10)
plot(exfdr,which="volcano")
dev.off()
bitmap(file="tr_2004_01-effectsize.png",width=6,height=4.5,pointsize=10)
plot(exfdr,which="effectsize",legend=T)
dev.off()


###################################################
### chunk number 21: 
###################################################
tab <- plot(exfdr,which="table")
tab[1:8,]


###################################################
### chunk number 22: 
###################################################
x <- c(rep(0,2),rep(1,3))
x


###################################################
### chunk number 23: 
###################################################
twilight.combi(x,pin=FALSE,bin=FALSE)


###################################################
### chunk number 24: 
###################################################
twilight.combi(x,pin=FALSE,bin=TRUE)


###################################################
### chunk number 25: 
###################################################
y <- c(rep(0,4),rep(1,4))
y


###################################################
### chunk number 26: 
###################################################
twilight.combi(y,pin=TRUE,bin=FALSE)


###################################################
### chunk number 27: 
###################################################
twilight.combi(y,pin=TRUE,bin=TRUE)


###################################################
### chunk number 28: 
###################################################
twilight.permute.pair(y,7,bal=TRUE)


###################################################
### chunk number 29: 
###################################################
Sys.sleep(30)

==> twilight_1.26.0.zip: twilight/doc/tr_2004_01.R <==
###################################################
### chunk number 1:  eval=FALSE
###################################################
## #line 47 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
## q(save="no")
## 


###################################################
### chunk number 2: 
###################################################
#line 50 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
library(splines)
library(stats)
library(golubEsets)
library(vsn)
oldopt <- options(digits=3)
on.exit( {options(oldopt)} )
options(width=75)


###################################################
### chunk number 3: 
###################################################
#line 112 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
data(Golub_Train)
golubNorm <- justvsn(Golub_Train)
id <- as.numeric(Golub_Train$ALL.AML) #$


###################################################
### chunk number 4: 
###################################################
#line 119 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
Golub_Train$ALL.AML #$
id


###################################################
### chunk number 5: 
###################################################
#line 131 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
library(twilight)
pval <- twilight.pval(golubNorm, id, B=100)


###################################################
### chunk number 6: 
###################################################
#line 138 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
data(expval)
expval


###################################################
### chunk number 7: 
###################################################
#line 144 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
class(expval)
names(expval)


###################################################
### chunk number 8: 
###################################################
#line 150 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
names(expval$result) #$


###################################################
### chunk number 9: 
###################################################
#line 156 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
expval$result[1:7,1:5] #$


###################################################
### chunk number 10: 
###################################################
#line 161 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
bitmap(file="tr_2004_01-scores.png",width=6,height=4.5,pointsize=10)
plot(expval,which="scores",grayscale=F,legend=F)
dev.off()
bitmap(file="tr_2004_01-qvalues.png",width=6,height=4.5,pointsize=10)
plot(expval,which="qvalues")
dev.off()


###################################################
### chunk number 11: 
###################################################
#line 179 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
expval$pi0 #$


###################################################
### chunk number 12: 
###################################################
#line 213 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
gene <- exprs(golubNorm)[pval$result$index[1],]
corr <- twilight.pval(golubNorm,gene,method="spearman",quant.ci=0.99,B=100)
corr


###################################################
### chunk number 13: 
###################################################
#line 222 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
corr$result[1:10,1:5] #$


###################################################
### chunk number 14: 
###################################################
#line 228 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
bitmap(file="tr_2004_01-corr.png",width=6,height=4.5,pointsize=10)
plot(corr,which="scores",grayscale=F,legend=F)
dev.off()


###################################################
### chunk number 15: 
###################################################
#line 269 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
yperm <- twilight.filtering(golubNorm,id,method="fc",num.perm=50,num.take=10)
dim(yperm)


###################################################
### chunk number 16: 
###################################################
#line 276 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
yperm <- yperm[-1,]
b <- twilight.pval(golubNorm,yperm[1,],method="fc",yperm=yperm)
hist(b$result$pvalue,col="gray",br=20)


###################################################
### chunk number 17: 
###################################################
#line 282 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
bitmap(file="tr_2004_01-hist.png",width=6,height=4.5,pointsize=10)
hist(b$result$pvalue,col="gray",br=20,main="",xlab="P-value")
dev.off()


###################################################
### chunk number 18: 
###################################################
#line 325 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
data(exfdr)
exfdr



###################################################
### chunk number 19: 
###################################################
#line 329 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
exfdr$result[1:5,6:9] #$


###################################################
### chunk number 20: 
###################################################
#line 335 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
bitmap(file="tr_2004_01-fdr.png",width=6,height=4.5,pointsize=10)
plot(exfdr,which="fdr",grayscale=F,legend=T)
dev.off()
bitmap(file="tr_2004_01-volcano.png",width=6,height=4.5,pointsize=10)
plot(exfdr,which="volcano")
dev.off()
bitmap(file="tr_2004_01-effectsize.png",width=6,height=4.5,pointsize=10)
plot(exfdr,which="effectsize",legend=T)
dev.off()


###################################################
### chunk number 21: 
###################################################
#line 368 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
tab <- plot(exfdr,which="table")
tab[1:8,]


###################################################
### chunk number 22: 
###################################################
#line 395 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
x <- c(rep(0,2),rep(1,3))
x


###################################################
### chunk number 23: 
###################################################
#line 400 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
twilight.combi(x,pin=FALSE,bin=FALSE)


###################################################
### chunk number 24: 
###################################################
#line 408 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
twilight.combi(x,pin=FALSE,bin=TRUE)


###################################################
### chunk number 25: 
###################################################
#line 417 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
y <- c(rep(0,4),rep(1,4))
y


###################################################
### chunk number 26: 
###################################################
#line 422 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
twilight.combi(y,pin=TRUE,bin=FALSE)


###################################################
### chunk number 27: 
###################################################
#line 430 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
twilight.combi(y,pin=TRUE,bin=TRUE)


###################################################
### chunk number 28: 
###################################################
#line 436 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
twilight.permute.pair(y,7,bal=TRUE)


###################################################
### chunk number 29: 
###################################################
#line 440 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphGc79e/R.INSTALL5b6e5d26/twilight/inst/doc/tr_2004_01.Rnw"
Sys.sleep(30)
